//=============================================================================
//  Unified IO - C++ interface for industrial IO cards
//  Copyright (C) 2000, UAB "BBD SOFT" ( http://www.bbdsoft.com/ )
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
//  The author of this program may be contacted at developers@bbdsoft.com
//=============================================================================


#ifndef _PCICFG_
#define _PCICFG_

#ifndef _PCIDEV_
   #include "pcidev.hpp"
#endif

//-----------------------------------------------------------------------------
namespace Uniio
{

class PCIDeviceInfo;

class _Export_UNIIO PCIConfig
{
   friend PCIDeviceInfo;
public:

   virtual ~PCIConfig ();

   virtual bool exists () const = 0;

   virtual void scanBus ( ) = 0;

   virtual unsigned char readChar ( const unsigned char inBus
                               , const unsigned char inSlot
                               , const unsigned char inOffset
                               ) const = 0;

   virtual unsigned short readShort ( const unsigned char inBus
                               , const unsigned char inSlot
                               , const unsigned char inOffset
                               ) const = 0;

   virtual unsigned long readLong ( const unsigned char inBus
                                , const unsigned char inSlot
                                , const unsigned char inOffset
                                ) const = 0;

   virtual void writeChar ( const unsigned char inBus
                            , const unsigned char inSlot
                            , const unsigned char inOffset
                            , const unsigned char inValue
                            )  = 0;

   virtual void writeShort ( const unsigned char inBus
                            , const unsigned char inSlot
                            , const unsigned char inOffset
                            , const unsigned short inValue
                            ) = 0;

   virtual void writeLong ( const unsigned char inBus
                            , const unsigned char inSlot
                            , const unsigned char inOffset
                            , const unsigned long inValue
                            ) = 0;

protected:
   PCIConfig ();

   void addDevice ( const unsigned char inBusNumber
                         , const unsigned char inSlotNumber
                         , void * inConfig
                         );


private:

   // disable copy constructor and assignment operator
   PCIConfig (const PCIConfig & );
   PCIConfig & operator = (const PCIConfig &);

}; // end PCIConfig class declaration

}; // end namespace

#endif
