//=============================================================================
//  Unified IO - C++ interface for industrial IO cards
//  Copyright (C) 2000, UAB "BBD SOFT" ( http://www.bbdsoft.com/ )
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
//  The author of this program may be contacted at developers@bbdsoft.com
//=============================================================================


#ifndef _BTRACE_
   #include "btrace.hpp"
#endif

#ifndef _AC28CARD_
   #include "ac28card.hpp"
#endif

#ifndef _STDEXCEPT_
   #include <stdexcept>
#endif

#ifndef _IOPORT_
   #include "ioport.hpp"
#endif

#ifndef _OSIFACE_
   #include "osiface.hpp"
#endif

using namespace std;
using namespace Uniio;

//-----------------------------------------------------------------------------
AC28Card::AC28Card ( const unsigned inBaseIOPort
                   , const unsigned inResetPort
                   , const bool inResetLevel )
  : Opto22AC28Base ("AC28", inResetLevel, inBaseIOPort, inResetPort)
{
BFUNCTRACE_DEVELOP ();

if (   inBaseIOPort != 0x100
    && inBaseIOPort != 0x140
    && inBaseIOPort != 0x180
    && inBaseIOPort != 0x280
   )
{
   logic_error exc ("AC28 card: invalid base IO port number specified.");
   throw exc;
} // endif 

if (   inResetPort != 0xE0
    && inResetPort != 0x1E0
    && inResetPort != 0x2E0
    && inResetPort != 0x3E0
   )
{
   logic_error exc ("AC28 card: invalid reset port number specified.");
   throw exc;
} // endif 

IOPort aResetPort ( resetPort () );
aResetPort.writeChar ( (resetLevel() ? 1 : 0));
OSInterface::sleep (30000);
aResetPort.writeChar ( (resetLevel() ? 0 : 1));

}  // end constructor


//-----------------------------------------------------------------------------
AC28Card::~AC28Card ()
{
BFUNCTRACE_DEVELOP ();
} // end destructor

